@@ -6,7 +6,10 @@ from django.http import HttpRequest, HttpResponse
 from django.core.signing import BadSignature, SignatureExpired
 from django.contrib.auth import get_user_model
 from django.core.exceptions import ObjectDoesNotExist
+from django.utils import translation
+from django.utils.translation import gettext as _
 
+from typing import List, Tuple, Callable
 from http import HTTPStatus
 
 from django_routeview import RouteView, urlpatterns
@@ -27,7 +30,7 @@ class APIView(RouteView):
     """
 
     enforce_authentification:bool = False
-    http_method_names:list[str] = ["get", "post", "put", "patch", "delete", "head", "options"]
+    http_method_names:List[str] = ["get", "post", "put", "patch", "delete", "head", "options"]
 
     _permissions_match_table = {
         'GET': "view",
@@ -49,7 +52,7 @@ class APIView(RouteView):
             self.name = self.__name__
 
         if self.route is None:
-            raise ValueError(f"APIView {self.__name__} requires a user defined route")
+            raise ValueError(_("APIView %(name)s requires a user defined route") % {'name': self.__name__})
 
     def _add_route_(self) -> None:
         if self.__name__ == "APIView":
@@ -64,28 +67,30 @@ class APIView(RouteView):
     def dispatch(self, request:HttpRequest, *args, **kwargs) -> APIResponse:
         headers = dict(request.headers)
 
-        if self.enforce_authentification:
+        with translation.override(request.GET.get('lang')):
 
-            if not 'Authorization' in headers:
-                return InvalidToken("Authentification required")
+            if self.enforce_authentification:
 
-            token = Token(signed_data=headers['Authorization'].split(" ")[-1])
-            try:
-                token.unsign()
-            except BadSignature:
-                return InvalidToken("Invalid signature")
-            except SignatureExpired:
-                return InvalidToken("Token expired")
+                if not 'Authorization' in headers:
+                    return InvalidToken(_("Authentication required"))
 
-            try:
-                user = get_user_model().objects.get(id=token.uid)
-            except (KeyError, ObjectDoesNotExist):
-                return InvalidToken("Invalid body")
+                token = Token(signed_data=headers['Authorization'].split(" ")[1])
+                try:
+                    token.unsign()
+                except SignatureExpired:
+                    return InvalidToken(_("Token expired"))
+                except BadSignature:
+                    return InvalidToken(_("Invalid signature"))
 
-            if not user.has_perm(f'api.{self._permissions_match_table[request.method]}_{self.name}') and not request.path_info.split("?")[0].strip("/").endswith(str(user.id)):
-                return NotAllowed()
+                try:
+                    user = get_user_model().objects.get(id=token.uid)
+                except (KeyError, ObjectDoesNotExist):
+                    return InvalidToken(_("Invalid body"))
 
-        return super().dispatch(request, *args, **kwargs)
+                if not user.has_perm(f'api.{self._permissions_match_table[request.method]}_{self.name}') and not request.path_info.split("?")[0].strip("/").endswith(str(user.id)):
+                    return NotAllowed()
+
+            return super().dispatch(request, *args, **kwargs)
 
     def http_method_not_allowed(self, request:HttpRequest, *args, **kwargs):
         return MethodNotImplemented()
@@ -94,4 +99,4 @@ class APIView(RouteView):
         return HttpResponse()
 
     def options(self, request:HttpRequest, *args, **kwargs) -> APIResponse:
-        return APIResponse(HTTPStatus.OK, "Available methods", self.http_method_names)
+        return APIResponse(HTTPStatus.OK, _("Available methods"), self.http_method_names)
