@@ -3,6 +3,7 @@ from django.contrib.auth import authenticate
 from django.utils.decorators import method_decorator
 from django.views.decorators.csrf import csrf_exempt
 from django.urls import get_resolver
+from django.utils.translation import gettext as _
 
 from http import HTTPStatus
 import json
@@ -20,15 +21,15 @@ class LoginView(APIView):
 
         user = authenticate(username=json_data['username'], password=json_data['password'])
         if user is not None:
-            token = Token(body={'uid': user.id})
+            token = Token({'uid': user.id})
             token.sign()
-            return APIResponse(HTTPStatus.OK, "User logged in", {'token': str(token), 'user': user.serialize(request)})
+            return APIResponse(HTTPStatus.OK, _("User logged in"), {'token': str(token), 'user': user.serialize(request)})
         else:
-            return APIResponse(HTTPStatus.UNAUTHORIZED, "Wrong user credentials")
+            return APIResponse(HTTPStatus.UNAUTHORIZED, _("Wrong user credentials"))
 
 
 class URLsView(APIView):
     route = ""
 
     def get(self, request, **kwargs) -> APIResponse:
-        return APIResponse(HTTPStatus.OK, "URLs available", sorted(set(view[1] for view in get_resolver(None).reverse_dict.values())))
+        return APIResponse(HTTPStatus.OK, _("URLs available"), sorted(set(view[1] for view in get_resolver(None).reverse_dict.values())))
